import React, {Component} from 'react'
import { is, fromJS } from 'immutable'
import { notification, Table} from 'antd'
import { RedoOutlined } from '@ant-design/icons'

import Api from '@/api'
import MKEmitter from '@/utils/events.js'
import UtilsDM from '@/utils/utils-datamanage.js'

import './index.scss'

class DebugTable extends Component {
  state = {
    columns: [
      {align: 'left', dataIndex: 'Sort', sorter: false, title: 'Sort', width: 120},
      {align: 'left', dataIndex: 'CDefine1', sorter: false, title: '文本1', width: 120},
      {align: 'left', dataIndex: 'CDefine2', sorter: false, title: '文本2', width: 120},
      {align: 'left', dataIndex: 'CDefine3', sorter: false, title: '文本3', width: 120},
      {align: 'left', dataIndex: 'CDefine4', sorter: false, title: '文本4', width: 120},
      {align: 'left', dataIndex: 'CDefine5', sorter: false, title: '文本5', width: 120},
      {align: 'left', dataIndex: 'CDefine6', sorter: false, title: '文本6', width: 120},
      {align: 'left', dataIndex: 'CDefine7', sorter: false, title: '文本7', width: 120},
    ],
    data: [],
    loading: false,
    setting: {
      interType: 'system',
      execute: true,
      dataresource: '(select * from s_debug_value_log where createuserid=@userid@) tb'
    },
    arr_field: 'ID,Sort,CDefine1,CDefine2,CDefine3,CDefine4,CDefine5,CDefine6,CDefine7'
  }

  /**
   * @description 子表数据加载
   */
  async loadmaindata () {
    const { setting, arr_field } = this.state

    this.setState({
      loading: true
    })

    let param = UtilsDM.getQueryDataParams(setting, arr_field, [], 'sort', 1, 9999, '')

    let result = await Api.genericInterface(param)

    if (result.status) {
      let start = 1

      this.setState({
        data: result.data.map((item, index) => {
          item.key = index
          item.$$uuid = item.ID || ''
          item.$Index = start + index + ''

          return item
        }),
        loading: false
      })
    } else {
      this.setState({
        loading: false
      })

      notification.error({
        top: 92,
        message: result.message,
        duration: 10
      })
    }
  }

  refreshByButtonResult = () => {
    const { loading } = this.state

    if (!loading) {
      this.loadmaindata()
    }
  }

  UNSAFE_componentWillMount() {
    // 组件加载时，获取菜单数据
    this.loadmaindata()
  }

  componentDidMount() {
    MKEmitter.addListener('refreshByButtonResult', this.refreshByButtonResult)
  }

  shouldComponentUpdate (nextProps, nextState) {
    return !is(fromJS(this.state), fromJS(nextState))
  }

  /**
   * @description 组件销毁，清除state更新
   */
  componentWillUnmount () {
    this.setState = () => {
      return
    }
    MKEmitter.removeListener('refreshByButtonResult', this.refreshByButtonResult)
  }

  render() {
    const { data, loading, columns } = this.state

    return (
      <div className="debugtable">
        <RedoOutlined className="mk-debug-reload" onClick={() => this.loadmaindata()}/>
        <Table size="middle" columns={columns} dataSource={data} loading={loading} scroll={{ x: '100%', y: false }}/>
      </div>
    )
  }
}

export default DebugTable